@@ -22,7 +22,6 @@ import java.util.HashSet;
 import java.util.List;
 import java.util.Properties;
 import java.util.Set;
-
 import javax.jbi.management.LifeCycleMBean;
 
 import org.apache.servicemix.jbi.deployer.AdminCommandsService;
@@ -31,10 +30,8 @@ import org.apache.servicemix.jbi.deployer.ServiceAssembly;
 import org.apache.servicemix.jbi.deployer.ServiceUnit;
 import org.apache.servicemix.jbi.deployer.SharedLibrary;
 import org.apache.servicemix.jbi.deployer.utils.ManagementSupport;
+import org.apache.servicemix.jbi.deployer.utils.StringUtils;
 import org.apache.servicemix.nmr.management.Nameable;
-import org.springframework.beans.factory.DisposableBean;
-import org.springframework.beans.factory.InitializingBean;
-import org.springframework.util.StringUtils;
 
 public class AdminCommandsImpl implements AdminCommandsService, Nameable {
 
@@ -444,18 +441,13 @@ public class AdminCommandsImpl implements AdminCommandsService, Nameable {
         return buffer.toString();
     }
 
+
     public void init() throws Exception {
-        deployer.getManagementStrategy().manageObject(this);
+        deployer.getEnvironment().manageObject(this);
     }
 
     public void destroy() throws Exception {
-        try {
-            deployer.getManagementStrategy().unmanageObject(this);
-        } catch (Exception e) {
-            // ignore ServiceUnavailableException thrown by Blueprint
-            // Service on dereference of ManagementStrategy proxy if its
-            // already in the process of itself shutting down
-        }
+        deployer.getEnvironment().unmanageObject(this);
     }
 
     public void setInstallationService(InstallationService installationService) {
