@@ -17,46 +17,32 @@
 package org.apache.servicemix.jbi.itests;
 
 import java.io.File;
-import java.io.FileInputStream;
-import java.io.IOException;
 import java.net.URL;
 import java.net.URLConnection;
-import java.util.List;
-import java.util.Properties;
-import java.util.HashMap;
-import java.util.Hashtable;
 import java.util.Enumeration;
+import java.util.List;
 import java.util.concurrent.CopyOnWriteArrayList;
 import java.util.concurrent.CountDownLatch;
 import java.util.concurrent.TimeUnit;
-
 import javax.jbi.component.Component;
 import javax.jbi.management.LifeCycleMBean;
 
 import org.apache.servicemix.jbi.deployer.ServiceAssembly;
-import org.apache.servicemix.jbi.deployer.handler.JBIDeploymentListener;
 import org.apache.servicemix.nmr.api.NMR;
-import org.osgi.framework.Bundle;
-import org.osgi.framework.BundleException;
-import org.junit.runner.RunWith;
 import org.junit.Test;
-import static org.junit.Assert.assertNotNull;
-import static org.junit.Assert.fail;
-import static org.junit.Assert.assertEquals;
-import static org.ops4j.pax.exam.CoreOptions.bootClasspathLibrary;
-import static org.ops4j.pax.exam.CoreOptions.felix;
-import static org.ops4j.pax.exam.CoreOptions.options;
-import static org.ops4j.pax.exam.CoreOptions.systemPackages;
-import static org.ops4j.pax.exam.CoreOptions.systemProperty;
-import static org.ops4j.pax.exam.CoreOptions.equinox;
-import static org.ops4j.pax.exam.CoreOptions.when;
-import static org.ops4j.pax.exam.container.def.PaxRunnerOptions.localRepository;
-
+import org.junit.runner.RunWith;
 import org.ops4j.pax.exam.Option;
-import org.ops4j.pax.exam.CoreOptions;
-import org.ops4j.pax.exam.options.MavenArtifactProvisionOption;
 import org.ops4j.pax.exam.junit.Configuration;
 import org.ops4j.pax.exam.junit.JUnit4TestRunner;
+import org.ops4j.pax.exam.options.MavenArtifactProvisionOption;
+import org.osgi.framework.Bundle;
+import org.osgi.framework.BundleException;
+
+import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertNotNull;
+import static org.junit.Assert.fail;
+import static org.ops4j.pax.exam.CoreOptions.*;
+import static org.ops4j.pax.exam.container.def.PaxRunnerOptions.localRepository;
 
 @RunWith(JUnit4TestRunner.class)
 public class IntegrationTest extends AbstractIntegrationTest {
@@ -247,6 +233,7 @@ public class IntegrationTest extends AbstractIntegrationTest {
 
             // hack system packages
             systemPackages("org.apache.karaf.main.spi;version=1.6.0", "org.apache.karaf.jaas.boot;version=1.6.0"),
+            systemPackages("org.osgi.util.tracker;version=1.5"),
             bootClasspathLibrary(mavenBundle("org.apache.karaf.jaas", "org.apache.karaf.jaas.boot")).afterFramework(),
             bootClasspathLibrary(mavenBundle("org.apache.karaf", "org.apache.karaf.main")).afterFramework(),
             bootClasspathLibrary(mavenBundle("org.apache.geronimo.specs", "geronimo-jta_1.1_spec")).beforeFramework(),
@@ -257,6 +244,9 @@ public class IntegrationTest extends AbstractIntegrationTest {
             // Felix Config Admin
             mavenBundle("org.apache.felix", "org.apache.felix.configadmin"),
             // Blueprint
+            mavenBundle("org.apache.servicemix.bundles", "org.apache.servicemix.bundles.asm"),
+            mavenBundle("org.apache.aries", "org.apache.aries.util"),
+            mavenBundle("org.apache.aries.proxy", "org.apache.aries.proxy"),
             mavenBundle("org.apache.aries.blueprint", "org.apache.aries.blueprint"),
             // Pax mvn handler
             mavenBundle("org.ops4j.pax.url", "pax-url-mvn"),
@@ -264,9 +254,10 @@ public class IntegrationTest extends AbstractIntegrationTest {
             // Bundles
             mavenBundle("org.apache.mina", "mina-core"),
             mavenBundle("org.apache.sshd", "sshd-core"),
-            mavenBundle("org.apache.karaf", "org.apache.karaf.management"),
             mavenBundle("org.apache.karaf.jaas", "org.apache.karaf.jaas.config"),
-            mavenBundle("org.apache.felix.gogo", "org.apache.felix.gogo.runtime"),
+            mavenBundle("org.apache.karaf.jaas", "org.apache.karaf.jaas.boot"),
+            mavenBundle("org.apache.karaf.jaas", "org.apache.karaf.jaas.modules"),
+            mavenBundle("org.apache.karaf.management", "org.apache.karaf.management.server"),
             mavenBundle("org.apache.karaf.shell", "org.apache.karaf.shell.console"),
             mavenBundle("org.apache.karaf.shell", "org.apache.karaf.shell.osgi"),
             mavenBundle("org.apache.karaf.shell", "org.apache.karaf.shell.log").noStart(),
@@ -276,7 +267,9 @@ public class IntegrationTest extends AbstractIntegrationTest {
             // Spring
             mavenBundle("org.apache.servicemix.bundles", "org.apache.servicemix.bundles.aopalliance"),
             mavenBundle("org.apache.servicemix.bundles", "org.apache.servicemix.bundles.cglib"),
+            mavenBundle("org.springframework", "spring-asm"),
             mavenBundle("org.springframework", "spring-core"),
+            mavenBundle("org.springframework", "spring-expression"),
             mavenBundle("org.springframework", "spring-beans"),
             mavenBundle("org.springframework", "spring-context"),
             mavenBundle("org.springframework", "spring-aop"),
@@ -289,11 +282,10 @@ public class IntegrationTest extends AbstractIntegrationTest {
             mavenBundle("org.apache.xbean", "xbean-naming"),
             mavenBundle("org.apache.servicemix.naming", "org.apache.servicemix.naming"),
             mavenBundle("org.apache.servicemix.bundles", "org.apache.servicemix.bundles.ant"),
-		    mavenBundle("javax.mail", "mail"),
+            mavenBundle("javax.mail", "mail"),
             mavenBundle("org.codehaus.woodstox", "stax2-api"),
             mavenBundle("org.codehaus.woodstox", "woodstox-core-asl"),
             mavenBundle("org.apache.servicemix.bundles", "org.apache.servicemix.bundles.wsdl4j"),
-            mavenBundle("org.apache.servicemix.specs", "org.apache.servicemix.specs.stax-api-1.0"),
             mavenBundle("org.apache.servicemix.specs", "org.apache.servicemix.specs.jbi-api-1.0"),
             mavenBundle("org.apache.servicemix.specs", "org.apache.servicemix.specs.activation-api-1.1"),
             mavenBundle("org.apache.geronimo.specs", "geronimo-jta_1.1_spec"),
@@ -305,7 +297,7 @@ public class IntegrationTest extends AbstractIntegrationTest {
             mavenBundle("org.apache.servicemix.nmr", "org.apache.servicemix.nmr.core"),
             mavenBundle("org.apache.servicemix.nmr", "org.apache.servicemix.nmr.spring"),
             mavenBundle("org.apache.servicemix.nmr", "org.apache.servicemix.nmr.osgi"),
-			mavenBundle("org.apache.servicemix.nmr", "org.apache.servicemix.nmr.management"),
+            mavenBundle("org.apache.servicemix.nmr", "org.apache.servicemix.nmr.management"),
             mavenBundle("org.apache.servicemix.jbi", "org.apache.servicemix.jbi.runtime"),
             mavenBundle("org.apache.servicemix.jbi", "org.apache.servicemix.jbi.deployer"),
             mavenBundle("org.apache.servicemix.jbi", "org.apache.servicemix.jbi.osgi"),
