@@ -267,6 +267,7 @@ public class ManagementTest extends AbstractIntegrationTest {
 
             // hack system packages
             systemPackages("org.apache.karaf.main.spi;version=1.0.0", "org.apache.karaf.jaas.boot;version=0.9.0"),
+            systemPackages("org.osgi.util.tracker;version=1.5"),
             bootClasspathLibrary(mavenBundle("org.apache.karaf.jaas", "org.apache.karaf.jaas.boot")).afterFramework(),
             bootClasspathLibrary(mavenBundle("org.apache.karaf", "org.apache.karaf.main")).afterFramework(),
             bootClasspathLibrary(mavenBundle("org.apache.geronimo.specs", "geronimo-jta_1.1_spec")).beforeFramework(),
@@ -288,18 +289,21 @@ public class ManagementTest extends AbstractIntegrationTest {
             mavenBundle("org.apache.mina", "mina-core"),
             mavenBundle("org.apache.sshd", "sshd-core"),
             mavenBundle("org.apache.karaf.jaas", "org.apache.karaf.jaas.config"),
-            mavenBundle("org.apache.felix", "org.apache.felix.gogo.runtime"),
+            mavenBundle("org.apache.karaf.jaas", "org.apache.karaf.jaas.boot"),
+            mavenBundle("org.apache.karaf.jaas", "org.apache.karaf.jaas.modules"),
+            mavenBundle("org.apache.karaf.management", "org.apache.karaf.management.server"),
             mavenBundle("org.apache.karaf.shell", "org.apache.karaf.shell.console"),
             mavenBundle("org.apache.karaf.shell", "org.apache.karaf.shell.osgi"),
             mavenBundle("org.apache.karaf.shell", "org.apache.karaf.shell.log").noStart(),
-            mavenBundle("org.apache.karaf", "org.apache.karaf.management"),
             
             equinox(),
 
             // Spring
             mavenBundle("org.apache.servicemix.bundles", "org.apache.servicemix.bundles.aopalliance"),
             mavenBundle("org.apache.servicemix.bundles", "org.apache.servicemix.bundles.cglib"),
+            mavenBundle("org.springframework", "spring-asm"),
             mavenBundle("org.springframework", "spring-core"),
+            mavenBundle("org.springframework", "spring-expression"),
             mavenBundle("org.springframework", "spring-beans"),
             mavenBundle("org.springframework", "spring-context"),
             mavenBundle("org.springframework", "spring-aop"),
@@ -316,7 +320,6 @@ public class ManagementTest extends AbstractIntegrationTest {
             mavenBundle("org.codehaus.woodstox", "stax2-api"),
             mavenBundle("org.codehaus.woodstox", "woodstox-core-asl"),
             mavenBundle("org.apache.servicemix.bundles", "org.apache.servicemix.bundles.wsdl4j"),
-            mavenBundle("org.apache.servicemix.specs", "org.apache.servicemix.specs.stax-api-1.0"),
             mavenBundle("org.apache.servicemix.specs", "org.apache.servicemix.specs.jbi-api-1.0"),
             mavenBundle("org.apache.servicemix.specs", "org.apache.servicemix.specs.activation-api-1.1"),
             mavenBundle("org.apache.geronimo.specs", "geronimo-jta_1.1_spec"),
